Macros
- trap
trap!method to wrap your code with to measure the time taken for the wrapped section execution.- trap_
mem trap_mem!method to wrap your code with to measure the time taken and the memory consumed for the wrapped section execution.
Enums
Functions
- measure_
time - Measures execution time and prints a timing line.
- measure_
time_ and_ memory - Measures execution time and memory/swap deltas.
- measure_
time_ and_ memory_ with_ color - Measures execution time and memory/swap deltas with colorized output.
- measure_
time_ with_ color - Measures execution time and prints a colorized timing line.